require(dplyr)
require(lme4)
require(here)
require(purrr)

# Load data
exp1 <- readRDS(file = here('clean_data', 'exp1.rds'))
exp2ab <- readRDS(file = here('clean_data', 'exp2ab.rds'))
exp2c <- readRDS(file = here('clean_data', 'exp2c.rds'))

# set reference levels

# exp 1
exp1$gazeCon <- factor(exp1$gazeCon, levels = c("hare", "stag"))
exp1$matrix <- factor(exp1$matrix, levels = c("PD", "Ass"))
exp1$trustFaces <- factor(exp1$trustFaces, levels = c("untrust", "trust"))

# exp 2ab
exp2ab$gazeCon <- factor(exp2ab$gazeCon, levels = c("hare", "stag"))
exp2ab$matrix <- factor(exp2ab$matrix, levels = c("PD", "Ass"))
exp2ab$trustFaces <- factor(exp2ab$trustFaces, levels = c("untrust", "trust"))
exp2ab$gazeMeanCheck <- factor(exp2ab$gazeMeanCheck, levels = c("no", "yes"))

# exp 2c
exp2c$gazeCon <- factor(exp2c$gazeCon, levels = c("hare", "stag"))
exp2c$matrix <- factor(exp2c$matrix, levels = c("PD", "Ass"))
exp2c$trustFaces <- factor(exp2c$trustFaces, levels = c("untrust", "trust"))

# Run models

#### exp 1 ####
# Add choiceBin variable which has the choice in 1/0 format rather than factor with labels
exp1 <- mutate(exp1, choiceBin = ifelse(choice == 'stag', 1, 0))

# Remove the straight gaze condition as we are not analysing it
exp1 <- filter(exp1, gazeCon != 'straight')

exp1.mod <- glmer(choiceBin ~ gazeCon * matrix * trustFaces + (1 + gazeCon | subject), 
                 family = binomial(), data = exp1, control=glmerControl(optimizer = c('bobyqa'), optCtrl=list(maxfun=10000)))

summary(exp1.mod)

#### exp2ab ####
exp2a <- filter(exp2ab, gazeMeanCheck == 'yes')
exp2a <- mutate(exp2a, choiceBin = ifelse(choice == 'stag', 1, 0))
exp2a <- filter(exp2a, gazeCon != 'straight')

exp2a.mod <- glmer(choiceBin ~ gazeCon * matrix * trustFaces + (1 + gazeCon | subject), family = binomial(), data = exp2a, 
                   control=glmerControl(optimizer = c('bobyqa'), optCtrl=list(maxfun=10000))) 

summary(exp2a.mod)

exp2b <- filter(exp2ab, gazeMeanCheck == 'no')
exp2b <- mutate(exp2b, choiceBin = ifelse(choice == 'stag', 1, 0))
exp2b <- filter(exp2b, gazeCon != 'straight')

exp2b.mod <- glmer(choiceBin ~ gazeCon * matrix * trustFaces + (1 + gazeCon | subject), family = binomial(), data = exp2b, 
                   control=glmerControl(optimizer = c('bobyqa'), optCtrl=list(maxfun=10000))) 

summary(exp2b.mod)

# exp2c ####
exp2c.mod <- glmer(choice ~ gazeCon * matrix * trustFaces + (1 + gazeCon | subject), 
                 family = binomial(), data = exp2c, control=glmerControl(optimizer = c('bobyqa'), optCtrl=list(maxfun=10000)))

summary(exp2c.mod)


#### test for non-zero cooperation rates in hare gaze conditions (evidence of random / Level 0) ####
# we take each of the hare gaze conditions and test whether the overall cooperation rate is sig > 0.
binom_func <- function(data) {
  
  data <- filter(data, gazeCon == 'hare')
  
  totals <- data %>% 
    group_by(matrix, trustFaces) %>% 
    summarise(n_coop = sum(choice == 'stag'), n_total = n())
  
  tests <- list()
  
  for(i in 1:nrow(totals)) {
    tests[[i]] <- binom.test(x = as.numeric(totals[i,3]), n = as.numeric(totals[i,4]), 
                             p = 0, alternative = c('greater'))
  }
  
  return(tests)
}

exp1_binoms <- binom_func(data = exp1)
exp2a_binoms <- binom_func(data = exp2a)
exp2c_binoms <- binom_func(data = exp2c)

print_binoms <- function(binoms) {
  for (i in 1:length(binoms)) print(binoms[[i]])
}

print_binoms(exp1_binoms)
print_binoms(exp2a_binoms)
print_binoms(exp2c_binoms)
