require(ggplot2)
require(dplyr) 
require(broom)
require(forcats)
require(here)
here <- here::here

# LOAD DATA
data <- read.csv(here('raw_data', 'exp2ab.csv'), stringsAsFactors=F)

#### CLEAN DATA ####
# because data was uploaded to database incrementally, we need to update the data frame so that it is in tidy long form
for (i in seq(1, nrow(data), 13)) {
  
  # Update all rows with data from last row
  
  data$gazeMeanCheck[i:(i+12)] <- data$gazeMeanCheck[i+12]
  data$econGameCheck[i:(i+12)] <- data$econGameCheck[i+12]
  data$svoCheck[i:(i+12)] <- data$svoCheck[i+12]
  data$quizCheck[i:(i+12)] <- data$quizCheck[i+12]
  data$svoAttempts[i:(i+12)] <- data$svoAttempts[i+12]
  data$heur1[i:(i+12)] <- data$heur1[i+12]
  data$heur2[i:(i+12)] <- data$heur2[i+12]
  data$heur3[i:(i+12)] <- data$heur3[i+12]
  data$heurRT[i:(i+12)] <- data$heurRT[i+12]
  data$reasonForExp[i:(i+12)] <- data$reasonForExp[i+12]
  data$reasonCorrect[i:(i+12)] <- data$reasonCorrect[i+12]
  data$reasonForExp[i:(i+12)] <- data$reasonForExp[i+12]
  data$ageCheck[i:(i+12)] <- data$ageCheck[i+12]
  data$ethnicityCheck[i:(i+12)] <- data$ethnicityCheck[i+12]
  data$check[i:(i+12)] <- data$check[i+12]
  
  # Extract svoType from svo1-9 (including count of how many types of each response were given)
  
  svoVec <- c(data$svo1[i+12], data$svo2[i+12], data$svo3[i+12], data$svo4[i+12], data$svo5[i+12], data$svo6[i+12], data$svo7[i+12], data$svo8[i+12], data$svo9[i+12])
  
  nProsoc <- length(grep('pro', svoVec))
  nIndiv <- length(grep('ind', svoVec))
  nCompet <- length(grep('comp', svoVec))
  
  data$nProsoc[i:(i+12)] <- as.numeric(nProsoc)
  data$nIndiv[i:(i+12)] <- as.numeric(nIndiv)
  data$nCompet[i:(i+12)] <- as.numeric(nCompet)
  
  if (data$nProsoc[i] > 5) {
    data$svoType[i:(i+12)] <- 'pro'
  } else if (data$nIndiv[i] > 5) {
    data$svoType[i:(i+12)] <- 'ind'
  } else if (data$nCompet[i] > 5) {
    data$svoType[i:(i+12)] <- 'comp'
  } else {
    data$svoType[i:(i+12)] <- 'na'
  }
 
  # We now have updated the entire data frame with the information from the last row.
  # Thus all that remains to be done is update trustworthy ratings and delete unnecessary rows.
   
}

# Remove the now superfluous last row for each individual dataset
deleteVector <- c(seq(13,nrow(data),13))
data <- data[-(deleteVector),]
  
# Update trial rows with trustworthy ratings
data <- data[order(data$subject, data$faceID),] 
tRateCol <- as.numeric(which(colnames(data)=="trustworthyRate"))
  
  for (i in seq(1, nrow(data), 2)) {
    data[i+1, tRateCol] <- data[i, tRateCol]
  }
  
# Remove all non-trial rows
data <- subset(data, trialCount > 0)
data <- data[order(data$subject, data$trialCount),] 
  
# Remove id column and svo1-9 columns 
data <- data[,-1]
svoCol1 <- as.numeric(which(colnames(data)=="svo1"))
svoCol9 <- as.numeric(which(colnames(data)=="svo9"))
data <- data[,-(svoCol1:svoCol9)]

## Set up factors etc ##
data$matrix <- factor(data$matrix, labels = c("Ass", "PD"))
data$gender <- factor(data$gender, labels = c("male", "female")) # 0 = male, 1 = female
data$trustFaces <- factor(data$trustFaces, labels = c("untrust", "trust")) # 0 = untrustworthy cue face, 1 = trustworthy cue face
data$ethnicity <- factor(data$ethnicity) # 1 = Hispanic/Latino, 2 = White/Caucasian, 3 = Black/African American, 4 = Pacific Islander, 5 = Asian, 6 = Native American, 7 = Two or more races, 8 = Other
data$education <- factor(data$education, ordered = TRUE) # 0 = none, 1 = primary, 2 = some high school, 3   = completed high school, 4 = some university, 5 = bachelor's, 6 = postgrad
data$economics <- factor(data$economics, labels = c("no", "yes")) # 0 = no, 1 = yes
# Note that a straight gaze condition was also included in this experiment, where the cue face did not shift its gaze but this was not analysed for the paper.
data$gazeCon <- factor(data$gazeCon, labels = c("hare", "straight", "stag")) # -1 = gaze at hare, 0 = gaze straight, 1 = gaze at stag
data$stagSide <- factor(data$stagSide, labels = c("left", "right")) # 0 = stag on left, 1 = stag on right
data$faceID <- factor(data$faceID)
data$choice <- factor(data$choice, labels = c("hare", "stag")) # 0 = hare, 1 = stag
data$choiceCongruent <- factor(data$choiceCongruent, labels = c("no", "yes", "straight")) # 0 = choice not congruent with gaze cue, 1 = choice congruent with gaze cue, 2 = straight gaze therefore congruence not applicable
data$choiceSide <- factor(data$choiceSide, labels = c("left", "right")) # 0 = chose animal on left, 1 = chose animal on right
data$reasonForExp <- factor(data$reasonForExp)
# Reasons were as follows (note that order of presentation was randomised):
# 0 = To investigate whether the gaze direction of the computer-generated faces would affect which animal people chose to hunt.
# 1 = To investigate whether self-identified ethnicity affects trustworthiness ratings.
# 2 = To investigate hidden racial biases.
# 3 = To determine people\'s aversion to risk taking.
# 4 = Don\'t know / Some other purpose.
data$reasonCorrect <- factor(data$reasonCorrect, labels = c("wrong", "correct")) # 1 = participant identified the correct reason
# Participants were asked to enter their age and ethnicity again at the end of the experiment to check for nuisance responding
data$check <- factor(data$check, labels = c("fail", "pass")) # 1 = age and ethnicity match, 0 = they don't match
data$quizAttempts <- as.numeric(data$quizAttempts)
data$quiz.Cat<-cut(data$quizAttempts, c(0, 1, 11), c("One", "Multiple"))
data$gazeMeaning <- factor(data$gazeMeaning, labels = c("meaningless", "meaningful")) # 0 = participant told that gaze signals were meaningless, 1 = replication of exp1
data$gazeMeanCheck <- factor(data$gazeMeanCheck) # question to determine whether they believed that the gaze cues were meaningful
data$econGameCheck <- factor(data$econGameCheck) # question about whether they had played a similar economic game before
data$quizCheck <- factor(data$quizCheck) # question about whether they had done the CRT before
data$svoCheck <- factor(data$svoCheck) # question about whether they had done the SVO measure before
data$svoType <- factor(data$svoType)
# Mark the CRT results. CRT taken from Frederick, 2005
data$heur1Check <- ifelse(data$heur1 == 5, 1, 0)
data$heur2Check <- ifelse(data$heur2 == 5, 1, 0)
data$heur3Check <- ifelse(data$heur3 == 47, 1, 0)
data$heurQuizResult <- rowSums(data[,c("heur1Check", "heur2Check", "heur3Check")])
data$heur1Check <- ifelse(data$heur1 == 5, "correct", "wrong")
data$heur2Check <- ifelse(data$heur2 == 5, "correct", "wrong")
data$heur3Check <- ifelse(data$heur3 == 47, "correct", "wrong")
# Update experiment codes - note that participants were analysed based on their responses to the question about whether they considered
# gaze signals meaningful or not
data$expCode <- ifelse(data$gazeMeanCheck == 'yes', 'exp2a', 'exp2b')

saveRDS(data, file = here('clean_data', 'exp2ab.rds'))



#### DEMOGRAPHICS ######
# Generate one line of data per participant to check demographics
seq <- seq(1,nrow(data),6)
demos <- data[seq,]
exp2a <- subset(demos, expCode == 'exp2a')
exp2b <- subset(demos, expCode == 'exp2b')

# exp2a
# age
mean(exp2a$age)
sd(exp2a$age)
# gender
table(exp2a$gender)
# education
# 0 = none, 1 = primary, 2 = some high school, 3   = completed high school, 4 = some university, 
# 5 = bachelor's, 6 = postgrad
table(exp2a$education)
# economics
table(exp2a$economics)
# quiz attempts
table(exp2a$quizAttempts)

# exp2b
# age
mean(exp2b$age)
sd(exp2b$age)
# gender
table(exp2b$gender)
# education
# 0 = none, 1 = primary, 2 = some high school, 3   = completed high school, 4 = some university, 
# 5 = bachelor's, 6 = postgrad
table(exp2b$education)
# economics
table(exp2b$economics)
# quiz attempts
table(exp2b$quizAttempts)





# Heuristic quiz #

# Question 1: A bat and a ball cost $1.10 in total. The bat costs $1.00 more than the ball. 
# How much does the ball cost? _____ cents.

# Correct answer: 5

# Question 2: If it takes 5 machines 5 minutes to make 5 widgets, how long 
# would it take 100 machines to make 100 widgets? _____ minutes.

# Correct answer: 5

# Question 3: In a lake, there is a patch of lily pads. Every day, the patch 
# doubles in size. If it takes 48 days for the patch to cover the entire lake, how long 
# would it take for the patch to cover half of the lake? _____ days.

# Correct answer: 47