require(dplyr)
require(stringr)
require(tidyr)
require(ggplot2)
require(here)

# LOAD DATA
data <- read.csv(here('raw_data', 'exp2c.csv'), header = T, stringsAsFactors = F)

# Remove columns that are not useful / we're not analysing
data <- select(data, -c(id, load, memoryTask, memoryNum, numberGuess))

# First separate non-completers from those who completed the experiment 
data <- data %>% 
  arrange(subject) %>% 
  group_by(subject) %>% 
  mutate(complete = ifelse(n() < 9, 'no', 'yes')) # We identify non-completers as those who have fewer than 9 rows of data

#Now create one dataset of complete experiments and one dataset for all the non-completes  
incompletes <- data[data$complete == 'no',]  
data <- data %>%
  filter(complete == 'yes')

### Check for those who have more than 9 rows of data as this indicates a bug with the experiment
data <- data %>% 
  group_by(subject) %>% 
  mutate(tooManyRows = ifelse(n() > 9, 'yes', 'no'))

#Create a dataset of those who have the right amount of rows and another dataset for
#those with too many
tooManyRows <- data[data$tooManyRows == 'yes',]  
data <- data %>%
  filter(tooManyRows == 'no')

#Remove the tooManyRows column from data
data <- data %>% 
  select(-tooManyRows)

#Take a dataset of the final row of data for each participant
finalRows <- data[data$trialCount == 0,]

#Remove final row (the final row is the only one where the trial count = 0) in the full dataset as we 
#will put the info from this row in all of the other rows that contain trial results
data <- data %>% 
  filter(trialCount != 0)

#Convert the SVO columns to an SVO type in final row dataset
finalRows$svoType <- NA
for (i in 1:nrow(finalRows)) {
  svoVec <- as.vector(finalRows[i,grep('svo1', colnames(finalRows)):grep('svo9', colnames(finalRows))])
  nPro <- length(grep('pro', svoVec))
  nInd <- length(grep('ind', svoVec))
  nComp <- length(grep('comp', svoVec))
  finalRows$svoType[i] <- case_when(
    nPro > 5 ~ 'pro',
    nInd > 5 ~ 'ind',
    nComp > 5 ~ 'comp', 
    nPro < 6 & nInd < 6 & nComp < 6 ~ 'nc'
  )
}

#Get rid of svo1:svo9 columns
finalRows <- finalRows %>% 
  select(-(svo1:svo9), -responseTime)

#Rename elapsedTime to totalTime as it's the total time they took to do the experiment
finalRows <- rename(finalRows, totalTime = elapsedTime)

#Remove columns from data that we are going to replace with columns from finalRows
data <- data %>% 
  select(-(svoAttempts:check))

#Remove columns from finalRows that we already have in data
finalRows <- finalRows %>% 
  select(subject, svoAttempts:totalTime, svoType)

#Merge data with finalRows to get updated values from last row
data <- left_join(data, finalRows, by = "subject")

#Update order of columns 
data <- data %>% 
  select(-elapsedTime, -trialEndTime, -date, -complete, everything(), elapsedTime, trialEndTime, date, complete) %>% 
  select(-complete) # remove complete column now as we know they are all complete


# Convert factor variables to factors

factorVars <- c('expCode', 'subject', 'gender', 'ethnicity', 'country', 'education', 'economics',
                'trustFaces', 'matrix', 'condition', 'faceID', 'gazeCon', 'stagSide', 
                'choice', 'choiceCongruent', 'choiceSide', 'viewedPayoff', 'gazeMeanCheck', 'econGameCheck',
                'svoCheck', 'quizCheck', 'reasonForExp', 'reasonCorrect', 'check')

data <- data %>%
  ungroup() %>% 
  mutate_at(factorVars,
            funs(as.factor))

#Update factor labels for key variables
data$matrix <- factor(data$matrix, labels = c("Ass", "PD"))
data$gender <- factor(data$gender, labels = c("male", "female"))
data$trustFaces <- factor(data$trustFaces, labels = c("untrust", "trust"))
data$education <- factor(data$education, ordered = TRUE)
data$economics <- factor(data$economics, labels = c("no", "yes"))
data$gazeCon <- factor(data$gazeCon, labels = c("hare", "stag"))
data$stagSide <- factor(data$stagSide, labels = c("left", "right"))
data$choice <- factor(data$choice, labels = c("hare", "stag"))
data$choiceCongruent <- factor(data$choiceCongruent, labels = c("no", "yes"))
data$choiceSide <- factor(data$choiceSide, labels = c("left", "right"))

#Update CRT results
data$heur1Check <- ifelse(data$heur1 == 5, 1, 0)
data$heur2Check <- ifelse(data$heur2 == 5, 1, 0)
data$heur3Check <- ifelse(data$heur3 == 47, 1, 0)
data$heurQuizResult <- rowSums(data[,c("heur1Check", "heur2Check", "heur3Check")])
data$heur1Check <- ifelse(data$heur1 == 5, "correct", "wrong")
data$heur2Check <- ifelse(data$heur2 == 5, "correct", "wrong")
data$heur3Check <- ifelse(data$heur3 == 47, "correct", "wrong")

#Save data
saveRDS(data, file = here('clean_data', 'exp2c.rds'))




